==> moonlight-1.20-2.16.14-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/set/BlockSetAPI.java <==
package net.mehvahdjukaar.moonlight.api.set;

import net.mehvahdjukaar.moonlight.api.misc.Registrator;
import net.mehvahdjukaar.moonlight.core.set.BlockSetInternal;
import net.minecraft.class_1792;
import net.minecraft.class_1935;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;

//Interface for Modders!
public class BlockSetAPI {

    /**
     * Registers a block set definition (like wood type, leaf type etc...)
     * Can be called only during mod startup (not during mod setup as it needs to run before registry events
     *
     * @param typeRegistry block set registry class instance. This contains all the logic that determines how a blockset
     *                     gets formed
     * @param <T>          IBlockType
     */
    public static synchronized <T extends BlockType> void registerBlockSetDefinition(BlockTypeRegistry<T> typeRegistry) {
        BlockSetInternal.registerBlockSetDefinition(typeRegistry);
    }

    /**
     * Use this function to add a (modded) block type finder manually. (i.e. for your wood type)
     * This is handy for block types that are unique and which can't be detected by the detection system defined in their BlockSetContainer class
     * Call during mod startup (not mod setup as it will be too late for this to affect block registration)
     *
     * @param type        the block type class you are registering this for (WoodType.class, LeafType.class...)
     * @param blockFinder Finder object that will provide the modded block type when the time is right
     */
    public static synchronized <T extends BlockType> void addBlockTypeFinder(Class<T> type, BlockType.SetFinder<T> blockFinder) {
        BlockSetInternal.addBlockTypeFinder(type, blockFinder);
    }

    /**
     * Use this function to remove incorrectly detected block types from your mod. The opposite
     * Call during mod startup (not mod setup as it will be too late for this to affect block registration)
     *
     * @param id id of the block that is getting erroneously added and should be removed
     */
    public static synchronized <T extends BlockType> void addBlockTypeRemover(Class<T> type, class_2960 id) {
        BlockSetInternal.addBlockTypeRemover(type, id);
    }

    public static <T extends BlockType> BlockTypeRegistry<T> getBlockSet(Class<T> type) {
        return BlockSetInternal.getBlockSetReg(type);
    }

    @FunctionalInterface
    public interface BlockTypeRegistryCallback<E, T extends BlockType> {
        void accept(Registrator<E> reg, Collection<T> wood);
    }

    /**
     * Add a registry function meant to register a set of blocks that use a specific wood type
     * Other entries like items can access the block types directly since it will be filled
     * Will be called (hopefully) after all other blocks registrations have been fired so the block set type is complete
     * Note that whatever gets registered here should in no way influence the block sets themselves (you shouldn't add new wood types here for example)
     *
     * @param registrationFunction registry function
     */
    public synchronized static <T extends BlockType> void addDynamicBlockRegistration(
            BlockTypeRegistryCallback<class_2248, T> registrationFunction, Class<T> blockType) {
        addDynamicRegistration(registrationFunction, blockType, class_7923.field_41175);
    }

    public static synchronized <T extends BlockType> void addDynamicItemRegistration(
            BlockTypeRegistryCallback<class_1792, T> registrationFunction, Class<T> blockType) {
        addDynamicRegistration(registrationFunction, blockType, class_7923.field_41178);
    }

    public static synchronized <T extends BlockType, E> void addDynamicRegistration(
            BlockSetAPI.BlockTypeRegistryCallback<E, T> registrationFunction, Class<T> blockType,
            class_2378<E> registry) {
        BlockSetInternal.addDynamicRegistration(registrationFunction, blockType, registry);
    }


    /**
     * Grabs all blockTypes registries
     */
    public static Collection<BlockTypeRegistry<?>> getRegistries() {
        return BlockSetInternal.getRegistries();
    }

    @Nullable
    public static <T extends BlockType> BlockTypeRegistry<T> getTypeRegistry(Class<T> typeClass) {
        return BlockSetInternal.getRegistry(typeClass);
    }

    /**
     * @return BlockType of the provided block
     */
    @Nullable
    public static <T extends BlockType> T getBlockTypeOf(class_1935 itemLike, Class<T> typeClass) {
        return BlockSetInternal.getBlockTypeOf(itemLike, typeClass);
    }


    /**
     * Tries changing an object block type. Returns null if it fails
     *
     * @param current        target item
     * @param originalMat    material from which the target item is made of
     * @param destinationMat desired block type
     */
    @Nullable
    public static Object changeType(Object current, BlockType originalMat, BlockType destinationMat) {
        return BlockType.changeType(current, originalMat, destinationMat);
    }

    //for items
    @Nullable
    public static class_1792 changeItemType(class_1792 current, BlockType originalMat, BlockType destinationMat) {
        return BlockType.changeItemType(current, originalMat, destinationMat);
    }

    //for blocks
    @Nullable
    public static class_2248 changeBlockType(class_2248 current, BlockType originalMat, BlockType destinationMat) {
        return BlockType.changeBlockType(current, originalMat, destinationMat);
    }
}

==> moonlight-1.21-2.25.0-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/set/BlockSetAPI.java <==
package net.mehvahdjukaar.moonlight.api.set;

import net.mehvahdjukaar.moonlight.api.misc.Registrator;
import net.mehvahdjukaar.moonlight.core.set.BlockSetInternal;
import net.minecraft.class_1792;
import net.minecraft.class_1935;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.function.Consumer;

//Interface for Modders!
public class BlockSetAPI {

    /**
     * Registers a block set definition (like wood type, leaf type etc...)
     * Can be called only during mod startup (not during mod setup as it needs to run before registry events
     *
     * @param typeRegistry block set registry class instance. This contains all the logic that determines how a blockset
     *                     gets formed
     * @param <T>          IBlockType
     */
    public static <T extends BlockType> void registerBlockSetDefinition(BlockTypeRegistry<T> typeRegistry) {
        BlockSetInternal.registerBlockSetDefinition(typeRegistry);
    }

    /**
     * Use this function to add a (modded) block type finder manually. (i.e. for your wood type)
     * This is handy for block types that are unique and which can't be detected by the detection system defined in their BlockSetContainer class
     * Call during mod startup (not mod setup as it will be too late for this to affect block registration)
     *
     * @param type        the block type class you are registering this for (WoodType.class, LeafType.class...)
     * @param blockFinder Finder object that will provide the modded block type when the time is right
     */
    @Deprecated
    public static <T extends BlockType> void addBlockTypeFinder(Class<T> type, BlockType.SetFinder<T> blockFinder) {
        BlockSetInternal.addBlockTypeFinder(type, blockFinder);
    }

    /**
     * Use this function to remove incorrectly detected block types from your mod. The opposite
     * Call during mod startup (not mod setup as it will be too late for this to affect block registration)
     *
     * @param id id of the block that is getting erroneously added and should be removed
     */
    @Deprecated
    public static <T extends BlockType> void addBlockTypeRemover(Class<T> type, class_2960 id) {
        BlockSetInternal.addBlockTypeRemover(type, id);
    }

    public static <T extends BlockType> BlockTypeRegistry<T> getBlockSet(Class<T> type) {
        return BlockSetInternal.getBlockSet(type);
    }

    @FunctionalInterface
    public interface BlockTypeRegistryCallback<E, T extends BlockType> {
        void accept(Registrator<E> reg, Collection<T> wood);
    }

    /**
     * Add a registry function meant to register a set of blocks that use a specific wood type
     * Other entries like items can access the block types directly since it will be filled
     * Will be called (hopefully) after all other blocks registrations have been fired so the block set type is complete
     * Note that whatever gets registered here should in no way influence the block sets themselves (you shouldn't add new wood types here for example)
     *
     * @param registrationFunction registry function
     */
    @Deprecated(forRemoval = true)
    public static <T extends BlockType> void addDynamicBlockRegistration(
            BlockTypeRegistryCallback<class_2248, T> registrationFunction, Class<T> blockType) {
        addDynamicRegistration(registrationFunction, blockType, class_7923.field_41175);
    }

    @Deprecated(forRemoval = true)
    public static <T extends BlockType> void addDynamicItemRegistration(
            BlockTypeRegistryCallback<class_1792, T> registrationFunction, Class<T> blockType) {
        addDynamicRegistration(registrationFunction, blockType, class_7923.field_41178);
    }

    @Deprecated(forRemoval = true)
    public static <T extends BlockType, E> void addDynamicRegistration(
            BlockSetAPI.BlockTypeRegistryCallback<E, T> registrationFunction, Class<T> blockType,
            class_2378<E> registry) {
        BlockSetInternal.addDynamicRegistration(registrationFunction, blockType, registry);
    }

    public static <E> void addDynamicRegistration(
            String myModId, Consumer<Registrator<E>> registrationFunction, class_2378<E> registry) {
        BlockSetInternal.addDynamicRegistration(myModId, registrationFunction, registry);
    }


    /**
     * Grabs all blockTypes registries
     */
    public static Collection<BlockTypeRegistry<?>> getRegistries() {
        return BlockSetInternal.getRegistries();
    }

    @Nullable
    public static<T extends BlockType> BlockTypeRegistry<T> getTypeRegistry(Class<T> typeClass) {
        return BlockSetInternal.getRegistry(typeClass);
    }

    /**
     * @return BlockType of the provided block
     */
    @Nullable
    public static <T extends BlockType> T getBlockTypeOf(class_1935 itemLike, Class<T> typeClass){
        return BlockSetInternal.getBlockTypeOf(itemLike, typeClass);
    }


    /**
     * Tries changing an object block type. Returns null if it fails
     *
     * @param current        target item
     * @param originalMat    material from which the target item is made of
     * @param destinationMat desired block type
     */
    @Nullable
    public static Object changeType(Object current, BlockType originalMat, BlockType destinationMat) {
        return BlockType.changeType(current, originalMat, destinationMat);
    }

    //for items
    @Nullable
    public static class_1792 changeItemType(class_1792 current, BlockType originalMat, BlockType destinationMat) {
        return BlockType.changeItemType(current, originalMat, destinationMat);
    }

    //for blocks
    @Nullable
    public static class_2248 changeBlockType(class_2248 current, BlockType originalMat, BlockType destinationMat) {
        return BlockType.changeBlockType(current, originalMat, destinationMat);
    }
}
